/*
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This code is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this code; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  */

/* Copyright (C) 2002 Ian Zimmerman <itz@speakeasy.org> */

#ifndef INCLUDE_GIM_CONNECTION_HH
#define INCLUDE_GIM_CONNECTION_HH

/* $Id: gim_connection.hh,v 1.3 2002/08/18 15:20:17 itz Exp $ */

#ifdef __cplusplus

extern "C" {
#include <libgim/gim_public.h>
#include <sys/types.h>
}

struct gim_exception {
  gim_exception(int what);
  int what;
  const char* to_string();
};

class gim_connection {
  friend class gim_abstract_handler;

public:
  gim_connection(struct gim_client_masks* p_masks, int vt = -1, const char* device = 0);
  ~gim_connection();
  void open() throw (struct gim_exception);
  void close() throw (struct gim_exception);
  void set_masks(const struct gim_client_masks* p_masks) throw (struct gim_exception);
  void get_masks(struct gim_client_masks* p_masks);
  void draw_pointer(int x, int y) throw (struct gim_exception);
  void stop() throw (struct gim_exception);
  void start() throw (struct gim_exception);
  int devinfo_len() throw (struct gim_exception);
  void devinfo(char* info, size_t info_size) throw (struct gim_exception);
  int servinfo_len() throw (struct gim_exception);
  void servinfo(char* info, size_t info_size) throw (struct gim_exception);
  void disable_paste() throw (struct gim_exception);
  int has_event() throw (struct gim_exception);
  void get_event(struct gim_event_t* p_ev) throw (struct gim_exception);

private:
  gim_client_masks masks;
  int vt;
  const char* device;
  int fd;
};

#endif // __cplusplus

#endif // INCLUDE_GIM_CONNECTION_HH
